Package 'healthindexni'

Title: What the Package Does (One Line, Title Case)
Description: What the package does (one paragraph).
Authors: First Last [aut, cre] (ORCID: YOUR-ORCID-ID)
Maintainer: First Last <[email protected]>
License: MIT + file LICENSE
Version: 0.0.0.9000
Built: 2026-06-05 08:32:28 UTC
Source: https://github.com/humaniverse/healthindexni

Help Index


Rate of Patient Admissions for Alcohol Related Conditions (2019)

Description

A dataset containing statistics on the rate of patient admissions for all alcohol-related admissions in each Northern Irish Council, 2019.

Usage

lives_alcohol_misuse

Format

A data frame with 11 rows and 6 variables:

ltla24_code

Local Authority Code

alcohol_admissions_rate_per_100k

Rate of patient admissions per 100k population, based on population numbers per HSCT, converted to Local Authority level. Patients are counted only once in the year in which they have an alcohol-related stay.

year

Time period

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://www.health-ni.gov.uk/publications/census-drug-and-alcohol-treatment-services-northern-ireland-30th-april-2019

https://data.nisra.gov.uk/


Percentage of Cancer Screening Uptake (2022-2023)

Description

A dataset containing statistics on the percentage of cancer screening uptake in each Northern Irish Council, 2022-2023.

Usage

lives_cancer_screening

Format

A data frame with 11 rows and 6 variables:

ltla24_code

Local Authority Code

cancer_screening_uptake

Percentage of cancer screening uptake; breast, bowel, and cervical cancer.

year

Time period

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://www.publichealth.hscni.net/publications/director-public-health-core-tables-2022


Percentage of Childhood Vaccine Coverage (2022-2023)

Description

A dataset containing statistics on childhood vaccine coverage (aged 6 and under) in each Northern Irish Council, 2022/23.

Usage

lives_child_vaccine_coverage

Format

A data frame with 11 rows and 6 variables:

ltla24_code

Local Authority Code

child_vaccine_coverage_percentage

Percentage of vaccine coverage. Includes childhood immunisation statistics (DtaP/IPV/Hib(HepB), MenB, Rotavirus, PCV, Hib/MenC, MMR1 (by age 2), MMR1 (by age 5), MMR2 (by age 5). Pre-School Booster)

year

School Year

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://www.publichealth.hscni.net/publications/director-public-health-core-tables-2022


Average percentage of Children Overweight/Obese (2022/23)

Description

A dataset containing statistics on the average percentage of children clinically classed as overweight and obese in each Council, 2022/23.

Usage

lives_childhood_overweight_obesity

Format

A data frame with 11 rows and 6 variables:

ltla24_code

Local Authority Code

overweight_obesity_percentage

Average percentage of children clinically classed as overweight and obese in P1 and P6 (aged 4/5 and 10/11)

year

School Year

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://data.nisra.gov.uk/


Percentage GSCE Attainment, including Maths and English (2022/23)

Description

A dataset containing statistics on the percentage of GSCE attainment, including Maths and English (A-C grade).

Usage

lives_gsce_attainment

Format

A data frame with 11 rows and 6 variables:

ltla24_code

Local Authority Code

gcse_qualifications_percent

Grade A-C percentage of GSCEs, including Maths and English on results day, by Council, end of school year 2023

year

School Year

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://data.nisra.gov.uk/


Percentage of People that Eat Healthy (2022-2023)

Description

A dataset containing statistics on fruit and vegetable consumption in each Northern Irish Council, 2022-23.

Usage

lives_healthy_eating

Format

A data frame with 11 rows and 6 variables:

ltla24_code

Local Authority Code

healthy_eating_percentage

Percentage of people that consume 5 portions or more of fruit and vegetable per day

year

Time period

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://www.health-ni.gov.uk/publications/health-survey-northern-ireland-first-results-202223


Percentage of Adults Diagnosed with High Blood Pressure (2023-2024)

Description

A dataset containing statistics on percentage of adults diagnosed with high blood pressure, by Council (2023-2024).

Usage

lives_high_blood_pressure

Format

A data frame with 11 rows and 6 variables:

ltla24_code

Local Authority Code

high_blood_pressure_percentage

Percentage of adults diagnosed with high blood pressure

year

Time period - Financial year

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://data.nisra.gov.uk/


Percentage of Babies Born Not at a Healthy Birth Weight (2022-2023)

Description

A dataset containing percentage babies born not at a healthy birth weight.

Usage

lives_low_birth_weight

Format

A data frame with 11 rows and 6 variables:

ltla24_code

Local Authority Code

low_birth_weight_percentage

Percentage of babies born not at a healthy birth weight

year

Time period

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://www.publichealth.hscni.net/publications/statistical-profile-childrens-health-northern-ireland-202223


Percentage of Pupil Absences (2021/22)

Description

A dataset containing statistics on the percentage of unauthorised school absences.

Usage

lives_pupil_absence

Format

A data frame with 11 rows and 6 variables:

ltla24_code

Local Authority Code

total_pupil_absence_percentage

Percentage of unauthorised school absences across primary, secondary, and special schools

year

School Year

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://data.nisra.gov.uk/


Percentage of Current Smokers (2022-2023)

Description

A dataset containing statistics on smoking status in each Northern Irish Council, 2022-23.

Usage

lives_smoking

Format

A data frame with 11 rows and 6 variables:

ltla24_code

Local Authority Code

smoking_percentage

Percentage of people that are current smokers

year

Time period

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://www.health-ni.gov.uk/publications/health-survey-northern-ireland-first-results-202223


Rates of teenage pregnancies per 1,000 (2020-22)

Description

A dataset containing statistics on the rate of teenage pregnancies per 1k.

Usage

lives_teenage_pregnancy

Format

A data frame with 11 rows and 6 variables:

ltla24_code

Local Authority Code

teenage_pregnancies_per_1k

Rate of teenage pregnancies per 1k where teenagers are aged between 13 and 19

year

3-year aggregated period

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://data.nisra.gov.uk/


Percentage of Young People in Education, Employment, and Training (2022/23)

Description

A dataset containing statistics on the percentage of young people (aged 16-18) who are in education, employment, and training.

Usage

lives_young_peoples_training

Format

A data frame with 11 rows and 6 variables:

ltla24_code

Local Authority Code

young_peoples_eet_percentage

Percentage of young people (aged 16-18 in Years 12-14) who are in education, employment, and training

year

School Year

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://data.nisra.gov.uk/


Mortality all causes rate per 100k (2020-22)

Description

A dataset containing statistics from an age-sex standardised rate for all causes of mortality per 100k, by Council (2020-22).

Usage

people_all_mortality

Format

A data frame with 11 rows and 6 variables:

ltla24_code

Local Authority Code

death_rate_per_100k

age-sex standardised rate for all causes of mortality per 100k

year

3-year aggregated period

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

Details

To note: England's Health Index uses a single year to calculate mortality rates from all causes. Northern Ireland only has 3-year aggregate data available.

https://data.nisra.gov.uk/


Average Measurement of Anxiety Out of 10 (2022-23)

Description

A dataset containing statistics of personal ratings on feelings of anxiety out of 10, by Council (2022-23).

Usage

people_anxiety

Format

A data frame with 11 rows and 6 variables:

ltla24_code

Local Authority Code

anxiety_score_out_of_10

Average personal ratings on feelings of anxiety out of 10 - 10 is most anxious, 1 is least anxious

year

Time period

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://www.ons.gov.uk/datasets/wellbeing-local-authority/editions/time-series/versions/4


Rate of Avoidable Deaths per 100k (2018-2022)

Description

A dataset containing statistics on age-standardised death rates per 100k, by Northern Irish Council (2018-2022).

Usage

people_avoidable_deaths

Format

A data frame with 11 rows and 6 variables:

ltla24_code

Local Authority Code

avoidable_deaths_per_100k

Age-standardised avoidable mortality rates per 100k

year

5-year aggregate period

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://data.nisra.gov.uk/


Cancer Registrations Percentage (2023-2024)

Description

A dataset containing statistics on cancer registration percentages, per Council (2023-2024).

Usage

people_cancer

Format

A data frame with 11 rows and 6 variables:

ltla24_code

Local Authority Code

cancer_percentage

Percentage of people with cancer per Council

year

Time period - Financial year

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://data.nisra.gov.uk/


Percentage Rate of Cardiovascular Conditions (CHD, Atrial Fibrillation, Heart Failure, Stroke & TIA) (2023/2024)

Description

A dataset containing statistics on the percentage of people who self-reported as having CHD, Atrial Fibrillation, Heart Failure, and/or Stroke & TIA in Northern Irish Council Areas.

Usage

people_cardiovascular_conditions

Format

A data frame with 11 rows and 6 variables:

ltla24_code

Local Authroity Code

cardiovascular_conditions_percentage

Percentage of people who self-reported as having CHD, Atrial Fibrillation, Heart Failure, and/or Stroke & TIA

year

Time period - financial year

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://data.nisra.gov.uk/


Percentage of People with Dementia

Description

A dataset containing statistics on the percentage of people medically diagnosed with dementia, by Council (2023-24).

Usage

people_dementia

Format

A data frame with 11 rows and 6 variables:

ltla24_code

Local Authority Code

dementia_percentage

Percentage of people medically diagnosed with dementia, per Council

year

Time period - Financial year

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://data.nisra.gov.uk/


Percentage prevalence of diabetes (2023-2024)

Description

A dataset containing statistics on the percentage prevalence of people with diabetes, by Northern Irish Council (2023-2024).

Usage

people_diabetes

Format

A data frame with 11 rows and 6 variables:

ltla24_code

Local Authority Code

diabetes_percentage

Percentage prevalence of diabetes (all types)

year

Time period

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://data.nisra.gov.uk/


Percentage of People Aged 15-64 with Long-Term Health Problem/Disability that Limits Daily Activities

Description

A dataset containing statistics on the percentage of people aged 15-64 with long-term health problem/disability that limits daily activities, by Council (2021).

Usage

people_disability_daily_activities

Format

A data frame with 11 rows and 6 variables:

ltla24_code

Local Authority Code

disability_activities_limited_percentage

percentage of people aged 15-64 with long-term health problem/disability that limits daily activities by a lot or by a little.

year

Year

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://www.nisra.gov.uk/publications/census-2021-main-statistics-health-disability-and-unpaid-care-tables


Average Measurement of Happiness Out of 10 (2022-23)

Description

A dataset containing statistics of personal ratings on feelings of happiness out of 10, by Council (2022-23).

Usage

people_happiness

Format

A data frame with 11 rows and 6 variables:

ltla24_code

Local Authority Code

happiness_score_out_of_10

Average personal ratings on feelings of happiness out of 10 - 10 is most happy, 1 is least happy

year

Time period

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://www.ons.gov.uk/datasets/wellbeing-local-authority/editions/time-series/versions/4


Rate of infant mortality (2018-2022)

Description

A dataset containing statistics on the rate of infant mortality in each Norther Irish Council, 2018-2022.

Usage

people_infant_mortality

Format

A data frame with 11 rows and 6 variables:

ltla24_code

Local Authority Code

infant_mortality_per_1k

Rate of infants per 1,000 that have died under the age of 1

year

Time period - five year aggregate

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://data.nisra.gov.uk/


Average Life Expectancy for Men and Women (2020-2022)

Description

A dataset containing statistics on average life expectancy for men and women, by Northern Irish Council (2020-2022).

Usage

people_life_expectancy

Format

A data frame with 11 rows and 6 variables:

ltla24_code

Local Authority Code

life_expectancy_combined

Average life expectancy for men and women

year

Time period - three year aggregate

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://www.ons.gov.uk/peoplepopulationandcommunity/healthandsocialcare/healthandlifeexpectancies/datasets/lifeexpectancyforlocalareasinenglandnorthernirelandandwalesbetween2001to2003and2020to2022


Average Measurement of Life Satisfaction Out of 10 (2022-23)

Description

A dataset containing statistics of personal ratings on feelings of life satisfaction out of 10, by Council (2022-23).

Usage

people_life_satisfaction

Format

A data frame with 11 rows and 6 variables:

ltla24_code

Local Authority Code

satisfaction_score_out_of_10

Average personal ratings on feelings of life satisfaction out of 10 - 10 is most satisfied, 1 is least satisfied

year

Time period

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://www.ons.gov.uk/datasets/wellbeing-local-authority/editions/time-series/versions/4


Average Measurement of Life Worthwhileness Out of 10 (2022-23)

Description

A dataset containing statistics of personal ratings on feelings of life worthwhileness out of 10, by Council (2022-23).

Usage

people_life_worthwhileness

Format

A data frame with 11 rows and 6 variables:

ltla24_code

Local Authority Code

worthwhile_score_out_of_10

Average personal ratings on feelings of life worthwhileness out of 10 - 10 is most worthwhile, 1 is least worthwhile

year

Time period

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://www.ons.gov.uk/datasets/wellbeing-local-authority/editions/time-series/versions/4


Adult Population Percentage with an Emotional, Psychological, or Mental Health Condition (2021)

Description

A dataset containing statistics on the percentage of adults (aged 15+) with an emotional, psychological, or mental health condition, by Council (2021).

Usage

people_mental_health

Format

A data frame with 11 rows and 6 variables:

ltla24_code

Local Authority Code

mental_health_percentage

Percentage of adult population (aged 15+) describing themselves as having an emotional, psychological, or mental health condition

year

Year

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://www.nisra.gov.uk/publications/census-2021-main-statistics-health-disability-and-unpaid-care-tables


Percentage Rate of Respiratory Conditions (Asthma and COPD) (2023/2024)

Description

A dataset containing statistics on the percentage of people who self-reported as having asthma and/or COPD in Northern Irish Council Areas.

Usage

people_respiratory_conditions

Format

A data frame with 11 rows and 6 variables:

ltla24_code

Local Authroity Code

respiratory_conditions_percentage

Percentage of people who self-reported as having asthma and/or COPD

year

Time period - financial year

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://data.nisra.gov.uk/


Rate of Self-Harm Related Admissions per 100,000 (2018/19-2022/23)

Description

A dataset containing statistics on the rate of self-harm related admissions per 100k, per Council (2018/19-2022/23).

Usage

people_self_harm

Format

A data frame with 11 rows and 6 variables:

ltla24_code

Local Authority Code

self_harm_per_100k

Rate of self-harm related admissions per 100k, standardised by age and sex with respect to the European Standard Population 2013

year

Grouped financial year aggregrate, 5 year period

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

Details

To note: England's Health Index collects rate of self-harm admissions per 100k in single-year increments. Only data available for Northern Ireland looks at 5-year aggregates across financial years.

https://data.nisra.gov.uk/


Deaths from Suicide (2019-2021)

Description

A dataset containing statistics from deaths by suicide, by Northern Irish Council.

Usage

people_suicide

Format

A data frame with 11 rows and 6 variables:

ltla24_code

Local Authority Code

suicide_rate_per_100k

Deaths from suicide (16+). Age standardised rate per 100,000.

year

Time period - 3 year aggregate

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://www.nisra.gov.uk/publications/suicide-statistics-2022


Air pollution (2019)

Description

A dataset containing population-weighted annual mean PM2.5 data for 2019, by Northern Irish Council Area. Uses the anthropogenic component.

Usage

places_air_pollution

Format

A data frame with 11 rows and 6 variables:

ltla24_code

Local Authority Code

air_pollution_weighted

Population-weighted annual mean PM2.5

year

Year

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://uk-air.defra.gov.uk/data/pcm-data


Percentage of Absolute Child Poverty (2017)

Description

A dataset containing statistics on the percentage of children (aged 15 and under) living in absolute low income families in each Council, 2017.

Usage

places_child_poverty

Format

A data frame with 11 rows and 6 variables:

ltla24_code

Local Authority Code

child_poverty_percentage

Percentage of children 15 and under living in absolute low incomes families (where a household's income is below 60% of the median income in 2010/11, adjusted for inflation).

year

Year

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://data.nisra.gov.uk/


Travel time to GPs

Description

A dataset containing the average (median) travel time (in minutes) to the nearest GP in each Local Government District. This is based on the travel time to the nearest GP in each Super Data Zone within a Local Government District.

Usage

places_gp_travel_time

Format

A data frame with 11 rows and 6 variables:

lgd14_code

Local Authority Code

gp_mean_travel_time

Mean travel time (in minutes) to the nearest GP among all the Super Data Zones within a Local Authority

year

Year the data was last updated

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

Details

Travel times are calculated using the TravelTime API (https://traveltime.com/apis/distance-matrix) and are based on travelling by public transport on a weekday morning.

https://openstreetmap.org/


Percentage Household Overcrowding (2017)

Description

A dataset containing statistics on the percentage of households experiencing household overcrowding, per Council (2017). Household overcrowding is typically defined as households with an occupancy rating of -1 or lower.

Usage

places_household_overcrowding

Format

A data frame with 11 rows and 6 variables:

ltla24_code

Local Authority Code

household_overcrowding_percentage

Percentage of households experiencing household overcrowding

year

Year

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://data.nisra.gov.uk/


Percentage of Households without Internet Access (2021/22)

Description

A dataset containing statistics on the percentage of households without internet access in Northern Irish Council Areas.

Usage

places_internet_access

Format

A data frame with 11 rows and 6 variables:

ltla24_code

Local Authority Code

no_internet_access_percentage

Percentage of households without access to the internet

year

Financial Year

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://data.nisra.gov.uk/


Rates of Noise Complaints per 1,000 (2023-2024)

Description

A dataset containing statistics on noise complaints per 1,000 people in Northern Irish Council Areas.

Usage

places_noise_complaints

Format

A data frame with 11 rows and 6 variables:

ltla24_code

Local Authority Code

noise_complaints_per_1k

Number of noise complaints per 1,000 people

year

Year

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://www.daera-ni.gov.uk/sites/default/files/publications/daera/Noise%20Complaint%20Statistics%20for%20NI%202023-24.PDF


Rates of Personal Crime per 1,000 (2017)

Description

A dataset containing statistics on 'personal crime' per 1,000 people in Northern Irish Council Areas. 'Personal crime' is defined as violence against the person, sexual offences, robbery, theft, criminal damage, and arson.

Usage

places_personal_crime

Format

A data frame with 11 rows and 6 variables:

ltla24_code

Local Authority Code

personal_crime_per_1k

Number of personal crimes per 1,000 people

year

Year

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://data.nisra.gov.uk/


Travel time to pharmacies

Description

A dataset containing the average (median) travel time (in minutes) to the nearest pharmacy in each Local Government District. This is based on the travel time to the nearest sports centre in each Super Data Zone within a Local Government District.

Usage

places_pharmacy_travel_time

Format

A data frame with 11 rows and 6 variables:

lgd14_code

Local Authority Code

pharmacy_mean_travel_time

Mean travel time (in minutes) to the nearest pharmacy among all the Super Data Zones within a Local Authority

year

Year the data was last updated

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

Details

Travel times are calculated using the TravelTime API (https://traveltime.com/apis/distance-matrix) and are based on travelling by public transport on a weekday morning.

https://openstreetmap.org/


Road safety (2023)

Description

A dataset containing number of people killed or seriously injured in each Northern Irish Council Area in 2023 (latest available data).

Usage

places_road_safety

Format

A data frame with 11 rows and 6 variables:

ltla24_code

Local Authority Code

road_accident_count

Number of people killed or seriously injured, per Local Authority

year

Year

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://www.psni.police.uk/about-us/our-publications-and-reports/official-statistics/road-traffic-collision-statistics


Travel time to sports facilities

Description

A dataset containing the average (median) travel time (in minutes) to the nearest sports centre in each Local Government District. This is based on the travel time to the nearest sports centre in each Super Data Zone within a Local Government District.

Usage

places_sports_centre_travel_time

Format

A data frame with 11 rows and 6 variables:

lgd14_code

Local Authority Code

sports_centre_mean_travel_time

Mean travel time (in minutes) to the nearest sports centre among all the Super Data Zones within a Local Authority

year

Year the data was last updated

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

Details

Travel times are calculated using the TravelTime API (https://traveltime.com/apis/distance-matrix) and are based on travelling by public transport on a weekday morning.

https://openstreetmap.org/


Percentage of People Experiencing Unemployment (2023)

Description

A dataset containing statistics on the percentage of people experiencing unemployment, claiming unemployed-related benefits.

Usage

places_unemployment

Format

A data frame with 11 rows and 6 variables:

ltla24_code

Local Authority Code

unemployment_percentage

Percentage of people experiencing unemployment and claiming unemployed-related benefits(Jobseeker’s Allowance plus out-of-work Universal Credit claimants who were claiming principally for the reason of being unemployed.)

year

Year

domain

Indicator domain - lives, people, or places

subdomain

Indicator subdomain

is_higher_better

Does higher scores correspond to better outcomes

...

https://data.nisra.gov.uk/