| Title: | What the Package Does (One Line, Title Case) |
|---|---|
| Description: | What the package does (one paragraph). |
| Authors: | First Last [aut, cre] (ORCID: YOUR-ORCID-ID) |
| Maintainer: | First Last <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.0.9000 |
| Built: | 2026-06-05 08:32:28 UTC |
| Source: | https://github.com/humaniverse/healthindexni |
A dataset containing statistics on the rate of patient admissions for all alcohol-related admissions in each Northern Irish Council, 2019.
lives_alcohol_misuselives_alcohol_misuse
A data frame with 11 rows and 6 variables:
Local Authority Code
Rate of patient admissions per 100k population, based on population numbers per HSCT, converted to Local Authority level. Patients are counted only once in the year in which they have an alcohol-related stay.
Time period
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing statistics on the percentage of cancer screening uptake in each Northern Irish Council, 2022-2023.
lives_cancer_screeninglives_cancer_screening
A data frame with 11 rows and 6 variables:
Local Authority Code
Percentage of cancer screening uptake; breast, bowel, and cervical cancer.
Time period
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
https://www.publichealth.hscni.net/publications/director-public-health-core-tables-2022
A dataset containing statistics on childhood vaccine coverage (aged 6 and under) in each Northern Irish Council, 2022/23.
lives_child_vaccine_coveragelives_child_vaccine_coverage
A data frame with 11 rows and 6 variables:
Local Authority Code
Percentage of vaccine coverage. Includes childhood immunisation statistics (DtaP/IPV/Hib(HepB), MenB, Rotavirus, PCV, Hib/MenC, MMR1 (by age 2), MMR1 (by age 5), MMR2 (by age 5). Pre-School Booster)
School Year
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
https://www.publichealth.hscni.net/publications/director-public-health-core-tables-2022
A dataset containing statistics on the average percentage of children clinically classed as overweight and obese in each Council, 2022/23.
lives_childhood_overweight_obesitylives_childhood_overweight_obesity
A data frame with 11 rows and 6 variables:
Local Authority Code
Average percentage of children clinically classed as overweight and obese in P1 and P6 (aged 4/5 and 10/11)
School Year
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing statistics on the percentage of GSCE attainment, including Maths and English (A-C grade).
lives_gsce_attainmentlives_gsce_attainment
A data frame with 11 rows and 6 variables:
Local Authority Code
Grade A-C percentage of GSCEs, including Maths and English on results day, by Council, end of school year 2023
School Year
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing statistics on fruit and vegetable consumption in each Northern Irish Council, 2022-23.
lives_healthy_eatinglives_healthy_eating
A data frame with 11 rows and 6 variables:
Local Authority Code
Percentage of people that consume 5 portions or more of fruit and vegetable per day
Time period
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
https://www.health-ni.gov.uk/publications/health-survey-northern-ireland-first-results-202223
A dataset containing statistics on percentage of adults diagnosed with high blood pressure, by Council (2023-2024).
lives_high_blood_pressurelives_high_blood_pressure
A data frame with 11 rows and 6 variables:
Local Authority Code
Percentage of adults diagnosed with high blood pressure
Time period - Financial year
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing percentage babies born not at a healthy birth weight.
lives_low_birth_weightlives_low_birth_weight
A data frame with 11 rows and 6 variables:
Local Authority Code
Percentage of babies born not at a healthy birth weight
Time period
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing statistics on the percentage of unauthorised school absences.
lives_pupil_absencelives_pupil_absence
A data frame with 11 rows and 6 variables:
Local Authority Code
Percentage of unauthorised school absences across primary, secondary, and special schools
School Year
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing statistics on smoking status in each Northern Irish Council, 2022-23.
lives_smokinglives_smoking
A data frame with 11 rows and 6 variables:
Local Authority Code
Percentage of people that are current smokers
Time period
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
https://www.health-ni.gov.uk/publications/health-survey-northern-ireland-first-results-202223
A dataset containing statistics on the rate of teenage pregnancies per 1k.
lives_teenage_pregnancylives_teenage_pregnancy
A data frame with 11 rows and 6 variables:
Local Authority Code
Rate of teenage pregnancies per 1k where teenagers are aged between 13 and 19
3-year aggregated period
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing statistics on the percentage of young people (aged 16-18) who are in education, employment, and training.
lives_young_peoples_traininglives_young_peoples_training
A data frame with 11 rows and 6 variables:
Local Authority Code
Percentage of young people (aged 16-18 in Years 12-14) who are in education, employment, and training
School Year
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing statistics from an age-sex standardised rate for all causes of mortality per 100k, by Council (2020-22).
people_all_mortalitypeople_all_mortality
A data frame with 11 rows and 6 variables:
Local Authority Code
age-sex standardised rate for all causes of mortality per 100k
3-year aggregated period
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
To note: England's Health Index uses a single year to calculate mortality rates from all causes. Northern Ireland only has 3-year aggregate data available.
A dataset containing statistics of personal ratings on feelings of anxiety out of 10, by Council (2022-23).
people_anxietypeople_anxiety
A data frame with 11 rows and 6 variables:
Local Authority Code
Average personal ratings on feelings of anxiety out of 10 - 10 is most anxious, 1 is least anxious
Time period
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
https://www.ons.gov.uk/datasets/wellbeing-local-authority/editions/time-series/versions/4
A dataset containing statistics on age-standardised death rates per 100k, by Northern Irish Council (2018-2022).
people_avoidable_deathspeople_avoidable_deaths
A data frame with 11 rows and 6 variables:
Local Authority Code
Age-standardised avoidable mortality rates per 100k
5-year aggregate period
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing statistics on cancer registration percentages, per Council (2023-2024).
people_cancerpeople_cancer
A data frame with 11 rows and 6 variables:
Local Authority Code
Percentage of people with cancer per Council
Time period - Financial year
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing statistics on the percentage of people who self-reported as having CHD, Atrial Fibrillation, Heart Failure, and/or Stroke & TIA in Northern Irish Council Areas.
people_cardiovascular_conditionspeople_cardiovascular_conditions
A data frame with 11 rows and 6 variables:
Local Authroity Code
Percentage of people who self-reported as having CHD, Atrial Fibrillation, Heart Failure, and/or Stroke & TIA
Time period - financial year
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing statistics on the percentage of people medically diagnosed with dementia, by Council (2023-24).
people_dementiapeople_dementia
A data frame with 11 rows and 6 variables:
Local Authority Code
Percentage of people medically diagnosed with dementia, per Council
Time period - Financial year
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing statistics on the percentage prevalence of people with diabetes, by Northern Irish Council (2023-2024).
people_diabetespeople_diabetes
A data frame with 11 rows and 6 variables:
Local Authority Code
Percentage prevalence of diabetes (all types)
Time period
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing statistics on the percentage of people aged 15-64 with long-term health problem/disability that limits daily activities, by Council (2021).
people_disability_daily_activitiespeople_disability_daily_activities
A data frame with 11 rows and 6 variables:
Local Authority Code
percentage of people aged 15-64 with long-term health problem/disability that limits daily activities by a lot or by a little.
Year
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing statistics of personal ratings on feelings of happiness out of 10, by Council (2022-23).
people_happinesspeople_happiness
A data frame with 11 rows and 6 variables:
Local Authority Code
Average personal ratings on feelings of happiness out of 10 - 10 is most happy, 1 is least happy
Time period
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
https://www.ons.gov.uk/datasets/wellbeing-local-authority/editions/time-series/versions/4
A dataset containing statistics on the rate of infant mortality in each Norther Irish Council, 2018-2022.
people_infant_mortalitypeople_infant_mortality
A data frame with 11 rows and 6 variables:
Local Authority Code
Rate of infants per 1,000 that have died under the age of 1
Time period - five year aggregate
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing statistics on average life expectancy for men and women, by Northern Irish Council (2020-2022).
people_life_expectancypeople_life_expectancy
A data frame with 11 rows and 6 variables:
Local Authority Code
Average life expectancy for men and women
Time period - three year aggregate
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing statistics of personal ratings on feelings of life satisfaction out of 10, by Council (2022-23).
people_life_satisfactionpeople_life_satisfaction
A data frame with 11 rows and 6 variables:
Local Authority Code
Average personal ratings on feelings of life satisfaction out of 10 - 10 is most satisfied, 1 is least satisfied
Time period
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
https://www.ons.gov.uk/datasets/wellbeing-local-authority/editions/time-series/versions/4
A dataset containing statistics of personal ratings on feelings of life worthwhileness out of 10, by Council (2022-23).
people_life_worthwhilenesspeople_life_worthwhileness
A data frame with 11 rows and 6 variables:
Local Authority Code
Average personal ratings on feelings of life worthwhileness out of 10 - 10 is most worthwhile, 1 is least worthwhile
Time period
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
https://www.ons.gov.uk/datasets/wellbeing-local-authority/editions/time-series/versions/4
A dataset containing statistics on the percentage of adults (aged 15+) with an emotional, psychological, or mental health condition, by Council (2021).
people_mental_healthpeople_mental_health
A data frame with 11 rows and 6 variables:
Local Authority Code
Percentage of adult population (aged 15+) describing themselves as having an emotional, psychological, or mental health condition
Year
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing statistics on the percentage of people who self-reported as having asthma and/or COPD in Northern Irish Council Areas.
people_respiratory_conditionspeople_respiratory_conditions
A data frame with 11 rows and 6 variables:
Local Authroity Code
Percentage of people who self-reported as having asthma and/or COPD
Time period - financial year
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing statistics on the rate of self-harm related admissions per 100k, per Council (2018/19-2022/23).
people_self_harmpeople_self_harm
A data frame with 11 rows and 6 variables:
Local Authority Code
Rate of self-harm related admissions per 100k, standardised by age and sex with respect to the European Standard Population 2013
Grouped financial year aggregrate, 5 year period
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
To note: England's Health Index collects rate of self-harm admissions per 100k in single-year increments. Only data available for Northern Ireland looks at 5-year aggregates across financial years.
A dataset containing statistics from deaths by suicide, by Northern Irish Council.
people_suicidepeople_suicide
A data frame with 11 rows and 6 variables:
Local Authority Code
Deaths from suicide (16+). Age standardised rate per 100,000.
Time period - 3 year aggregate
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
https://www.nisra.gov.uk/publications/suicide-statistics-2022
A dataset containing population-weighted annual mean PM2.5 data for 2019, by Northern Irish Council Area. Uses the anthropogenic component.
places_air_pollutionplaces_air_pollution
A data frame with 11 rows and 6 variables:
Local Authority Code
Population-weighted annual mean PM2.5
Year
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
https://uk-air.defra.gov.uk/data/pcm-data
A dataset containing statistics on the percentage of children (aged 15 and under) living in absolute low income families in each Council, 2017.
places_child_povertyplaces_child_poverty
A data frame with 11 rows and 6 variables:
Local Authority Code
Percentage of children 15 and under living in absolute low incomes families (where a household's income is below 60% of the median income in 2010/11, adjusted for inflation).
Year
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing the average (median) travel time (in minutes) to the nearest GP in each Local Government District. This is based on the travel time to the nearest GP in each Super Data Zone within a Local Government District.
places_gp_travel_timeplaces_gp_travel_time
A data frame with 11 rows and 6 variables:
Local Authority Code
Mean travel time (in minutes) to the nearest GP among all the Super Data Zones within a Local Authority
Year the data was last updated
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
Travel times are calculated using the TravelTime API (https://traveltime.com/apis/distance-matrix) and are based on travelling by public transport on a weekday morning.
A dataset containing statistics on the percentage of households experiencing household overcrowding, per Council (2017). Household overcrowding is typically defined as households with an occupancy rating of -1 or lower.
places_household_overcrowdingplaces_household_overcrowding
A data frame with 11 rows and 6 variables:
Local Authority Code
Percentage of households experiencing household overcrowding
Year
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing statistics on the percentage of households without internet access in Northern Irish Council Areas.
places_internet_accessplaces_internet_access
A data frame with 11 rows and 6 variables:
Local Authority Code
Percentage of households without access to the internet
Financial Year
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing statistics on noise complaints per 1,000 people in Northern Irish Council Areas.
places_noise_complaintsplaces_noise_complaints
A data frame with 11 rows and 6 variables:
Local Authority Code
Number of noise complaints per 1,000 people
Year
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
https://www.daera-ni.gov.uk/sites/default/files/publications/daera/Noise%20Complaint%20Statistics%20for%20NI%202023-24.PDF
A dataset containing statistics on 'personal crime' per 1,000 people in Northern Irish Council Areas. 'Personal crime' is defined as violence against the person, sexual offences, robbery, theft, criminal damage, and arson.
places_personal_crimeplaces_personal_crime
A data frame with 11 rows and 6 variables:
Local Authority Code
Number of personal crimes per 1,000 people
Year
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing the average (median) travel time (in minutes) to the nearest pharmacy in each Local Government District. This is based on the travel time to the nearest sports centre in each Super Data Zone within a Local Government District.
places_pharmacy_travel_timeplaces_pharmacy_travel_time
A data frame with 11 rows and 6 variables:
Local Authority Code
Mean travel time (in minutes) to the nearest pharmacy among all the Super Data Zones within a Local Authority
Year the data was last updated
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
Travel times are calculated using the TravelTime API (https://traveltime.com/apis/distance-matrix) and are based on travelling by public transport on a weekday morning.
A dataset containing number of people killed or seriously injured in each Northern Irish Council Area in 2023 (latest available data).
places_road_safetyplaces_road_safety
A data frame with 11 rows and 6 variables:
Local Authority Code
Number of people killed or seriously injured, per Local Authority
Year
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
A dataset containing the average (median) travel time (in minutes) to the nearest sports centre in each Local Government District. This is based on the travel time to the nearest sports centre in each Super Data Zone within a Local Government District.
places_sports_centre_travel_timeplaces_sports_centre_travel_time
A data frame with 11 rows and 6 variables:
Local Authority Code
Mean travel time (in minutes) to the nearest sports centre among all the Super Data Zones within a Local Authority
Year the data was last updated
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...
Travel times are calculated using the TravelTime API (https://traveltime.com/apis/distance-matrix) and are based on travelling by public transport on a weekday morning.
A dataset containing statistics on the percentage of people experiencing unemployment, claiming unemployed-related benefits.
places_unemploymentplaces_unemployment
A data frame with 11 rows and 6 variables:
Local Authority Code
Percentage of people experiencing unemployment and claiming unemployed-related benefits(Jobseeker’s Allowance plus out-of-work Universal Credit claimants who were claiming principally for the reason of being unemployed.)
Year
Indicator domain - lives, people, or places
Indicator subdomain
Does higher scores correspond to better outcomes
...